# aviary.hotpotqa

The HotPotQA environment asks agents to perform multi-hop question answering on the HotPotQA dataset [1].

## References

[1] Yang et al. [HotpotQA: A Dataset for Diverse,
Explainable Multi-Hop Question Answering](https://aclanthology.org/D18-1259/). EMNLP, 2018.

## Installation

To install the HotPotQA environment, run the following command:

```bash
pip install 'fhaviary[hotpotqa]'
```
